X-Original-To: pgsql-performance-postgresql.org@postgresql.org Received: from localhost (mx1.hub.org [200.46.208.251]) by postgresql.org (Postfix) with ESMTP id 70EC19FA38F for ; Tue, 13 Jun 2006 21:11:05 -0300 (ADT) Received: from postgresql.org ([200.46.204.71]) by localhost (mx1.hub.org [200.46.208.251]) (amavisd-new, port 10024) with ESMTP id 47095-10 for ; Tue, 13 Jun 2006 21:10:54 -0300 (ADT) X-Greylist: from auto-whitelisted by SQLgrey- Received: from linda-4.paradise.net.nz (bm-4a.paradise.net.nz [203.96.152.183]) by postgresql.org (Postfix) with ESMTP id D3B129FA1A8 for ; Tue, 13 Jun 2006 21:10:52 -0300 (ADT) Received: from smtp-3.paradise.net.nz (tclsnelb1-src-1.paradise.net.nz [203.96.152.172]) by linda-4.paradise.net.nz (Paradise.net.nz) with ESMTP id <0J0T0033WPU34N@linda-4.paradise.net.nz> for pgsql-performance@postgresql.org; Wed, 14 Jun 2006 12:10:51 +1200 (NZST) Received: from [192.168.1.11] (218-101-28-235.dsl.clear.net.nz [218.101.28.235]) by smtp-3.paradise.net.nz (Postfix) with ESMTP id 934B9C2FD05; Wed, 14 Jun 2006 12:10:50 +1200 (NZST) Date: Wed, 14 Jun 2006 12:10:43 +1200 From: Mark Kirkwood Subject: Re: Solaris shared_buffers anomaly? In-reply-to: <448F3A6E.6080908@ca.sophos.com> To: mischa@ca.sophos.com Cc: pgsql-performance@postgresql.org Message-id: <448F5403.7030903@paradise.net.nz> MIME-version: 1.0 Content-type: text/plain; format=flowed; charset=ISO-8859-1 Content-transfer-encoding: 7bit User-Agent: Thunderbird 1.5 (X11/20060417) References: <1150151282.14661.42.camel@tigger> <20060613000441.GI8588@kenobi.snowman.net> <20060613200810.GZ34196@pervasive.com> <448F3A6E.6080908@ca.sophos.com> X-Virus-Scanned: Maia Mailguard 1.0.1 X-Archive-Number: 200606/230 X-Sequence-Number: 19587 Mischa Sandberg wrote: > Jim C. Nasby wrote: > ... >> Actually, in 8.1.x I've seen some big wins from greatly increasing the >> amount of shared_buffers, even as high as 50% of memory, thanks to the >> changes made to the buffer management code. ... > > Anyone else run into a gotcha that one of our customers ran into? > PG 7.4.8 running on Solaris 2.6, USparc w 4GB RAM. > Usually about 50 active backends. > (No reason to believe this wouldn't apply to 8.x). > > Initially shared_buffers were set to 1000 (8MB). > Then, we moved all apps but the database server off the box. > > Raised shared_buffers to 2000 (16MB). > Modest improvement in some frequent repeated queries. > > Raised shared_buffers to 16000 (128MB). > DB server dropped to a CRAWL. > > vmstat showed that it was swapping like crazy. > Dropped shared_buffers back down again. Swapping stopped. > > Stared at "ps u" a lot, and realized that the shm seg appeared to > be counted as part of the resident set (RSS). > Theory was that the kernel was reading the numbers the same way, > and swapping out resident sets, since they obviously wouldn't > all fit in RAM :-) > > Anyone from Sun reading this list, willing to offer an opinion? > A while ago I ran 7.4.? on a Solaris 2.8 box (E280 or E220 can't recall) with 2G of ram - 40 users or so with shared_buffers = approx 12000 - with no swapping I recall (in fact I pretty sure there was free memory!). I suspect something else is your culprit - what is work_mem (or sort_mem) set to? I'm thinking that you have this high and didn't have much memory headroom to begin with, so that upping shared_buffers from 16MB -> 128MB tipped things over the edge! Cheers Mark